/*
 * LittleLibrary.java
 *
 * Created on 17 October 2002
 *
 * Test for interchange with EMF
 */

package startup;

import Vsml.repository.*;
import Vsml.repository.implementation.*;
import Vsml.AS.*;
import uk.ac.ukc.cs.kmf.ocl.*;
import uk.ac.ukc.cs.kmf.ocl.implementations.*;
import java.io.*;
import java.util.*;
import uk.ac.ukc.cs.kmf.ocl.utils.*;
import javax.swing.*;
import java.awt.event.*;

/**
 *
 * @author  sjhk
 */
public class LittleLibrary {
    
    /** LittleLibrary test example */
    public LittleLibrary() {
    }
    
    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        
        //create repository
        IVsmlRepository rep = new VsmlRepository();
        String ASpath = "Vsml.AS.";
        String SDpath = "Vsml.SD.";
        String Sempath = "Vsml.Semantics.";
        System.out.println("Repository created.");
        
        //replace default builders with own
        //AS builders
        rep.addLifecycle(ASpath+"Association", new lifecycle.AssociationLifecycle(rep));
        rep.addLifecycle(ASpath+"AssociationEnd", new lifecycle.AssociationEndLifecycle(rep));
        rep.addLifecycle(ASpath+"Class", new lifecycle.Class_Lifecycle(rep));
        rep.addLifecycle(ASpath+"Package", new lifecycle.Package_Lifecycle(rep));  
                        
        //get required builders from repository
        //AS builders
        lifecycle.Class_Lifecycle class_b = (lifecycle.Class_Lifecycle)(rep.getLifecycle(ASpath+"Class"));
        lifecycle.AssociationLifecycle assoc_b = (lifecycle.AssociationLifecycle)(rep.getLifecycle(ASpath+"Association"));
        lifecycle.Package_Lifecycle package_b = (lifecycle.Package_Lifecycle)(rep.getLifecycle(ASpath+"Package"));
        System.out.println("Builders extracted.");

        //CREATE LittleLibrary
        //create package
        IPackage p_Library = (IPackage)package_b.build(OCL.String("Library"));
        System.out.println("Built all packages.");
        

        //create classes and add to package
        IClass c_System = class_b.build(p_Library,OCL.String("System"));
        IClass c_Copy = class_b.build(p_Library,OCL.String("Copy"));
        IClass c_Publication = class_b.build(p_Library,OCL.String("Publication"));
        IClass c_Loan = class_b.build(p_Library,OCL.String("Loan"));
        IClass c_Reservation = class_b.build(p_Library,OCL.String("Reservation"));
        IClass c_User = class_b.build(p_Library,OCL.String("User"));
        IClass c_Boolean = class_b.build(p_Library,OCL.String("Boolean"));
        IClass c_String = class_b.build(p_Library,OCL.String("String"));
        System.out.println("Built all classes.");
        
        //create binary associations
        assoc_b.build(p_Library,c_System,c_Publication,OCL.String("publication"),OCL.Integer(0),null,
            OCL.String("system"),OCL.Integer(1),OCL.Integer(1));
        assoc_b.build(p_Library,c_System,c_User,OCL.String("user"),OCL.Integer(0),null,
            OCL.String("system"),OCL.Integer(1),OCL.Integer(1));
        assoc_b.build(p_Library,c_Copy,c_Publication,OCL.String("publication"),OCL.Integer(1),OCL.Integer(1),
            OCL.String("copy"),OCL.Integer(0),null);
        assoc_b.build(p_Library,c_Loan,c_Copy,OCL.String("copy"),OCL.Integer(1),OCL.Integer(1),
            OCL.String("loan"),OCL.Integer(0),null);        
        assoc_b.build(p_Library,c_Loan,c_User,OCL.String("user"),OCL.Integer(1),OCL.Integer(1),
            OCL.String("loan"),OCL.Integer(0),null);
        System.out.println("Built all binary associations.");
            
        //create unary associations
        assoc_b.build(p_Library,c_User,c_String,OCL.String("name"),OCL.Integer(1),OCL.Integer(1));        
        assoc_b.build(p_Library,c_Publication,c_String,OCL.String("title"),OCL.Integer(1),OCL.Integer(1));
        //assoc_b.build(p_Library,c_Copy,c_Loan,OCL.String("loan"),OCL.Integer(0),OCL.Integer(1));    
        assoc_b.build(p_Library,c_Copy,c_Loan,OCL.String("currentLoan"),OCL.Integer(0),OCL.Integer(1));
        System.out.println("Built all unary associations.");
                
        VsmlBrowser browser = new VsmlBrowser();
        browser.setRep(rep);
        browser.show();
    }
    
}
